# Кодекс поведения Contributor Covenant

## Наше обязательство

Мы, как участники, контрибьюторы и лидеры, обязуемся сделать участие в нашем сообществе свободным от преследований для всех, независимо от возраста, размера тела, видимых или невидимых ограничений возможностей, этнической принадлежности, половых характеристик, гендерной идентичности и самовыражения, уровня опыта, образования, социально-экономического статуса, национальности, внешнего вида, расы, религии или сексуальной идентичности и ориентации.

Мы обязуемся действовать и взаимодействовать таким образом, чтобы способствовать созданию открытого, гостеприимного, разнообразного, инклюзивного и здорового сообщества.

## Наши стандарты

Примеры поведения, способствующего созданию благоприятной среды для нашего сообщества, включают:

* Проявление эмпатии и доброты по отношению к другим людям
* Уважение к различным мнениям, точкам зрения и опыту
* Предоставление и достойное принятие конструктивной обратной связи
* Принятие ответственности и извинение перед теми, кто пострадал от наших ошибок, а также извлечение уроков из этого опыта
* Фокусирование на том, что лучше не только для нас как индивидуумов, но и для всего сообщества в целом

Примеры неприемлемого поведения включают:

* Использование сексуализированного языка или образов, а также сексуальных домогательств или предложений любого рода  
* Троллинг, оскорбительные или уничижительные комментарии, а также личные или политические нападки  
* Публичное или частное преследование  
* Публикация личной информации других лиц, такой как физический или электронный адрес, без их явного разрешения  
* Другое поведение, которое можно разумно считать неуместным в профессиональной обстановке

## Обязанности по обеспечению соблюдения

Лидеры сообщества несут ответственность за разъяснение и обеспечение соблюдения наших стандартов приемлемого поведения и предпримут соответствующие и справедливые корректирующие действия в ответ на любое поведение, которое они сочтут неприемлемым, угрожающим, оскорбительным или вредным.

Лидеры сообщества имеют право и обязанность удалять, редактировать или отклонять комментарии, коммиты, код, правки вики, вопросы и другие вклады, которые не соответствуют настоящему Кодексу поведения, и будут сообщать причины решений о модерации, когда это уместно.

## Область применения

Этот Кодекс поведения применяется во всех сообществах, а также когда  
индивидуум официально представляет сообщество в публичных пространствах.  
Примеры представления нашего сообщества включают использование официального адреса электронной почты,  
публикацию через официальный аккаунт в социальных сетях или выступление в качестве назначенного  
представителя на онлайн- или оффлайн-мероприятии.

## Принуждение

Случаи оскорбительного, преследующего или иного неприемлемого поведения могут быть
сообщены лидерам сообщества, ответственным за обеспечение соблюдения, по адресу
aw@funstory.ai .
Все жалобы будут рассмотрены и расследованы оперативно и справедливо.

Все лидеры сообщества обязаны уважать конфиденциальность и безопасность
сообщившего о любом инциденте.

## Руководство по применению

Лидеры сообщества будут следовать этим Руководствам по воздействию на сообщество при определении последствий для любых действий, которые они сочтут нарушающими данный Кодекс поведения:

### 1. Коррекция

**Влияние на сообщество**: Использование неуместного языка или другое поведение, которое считается непрофессиональным или нежелательным в сообществе.

**Последствие**: Частное письменное предупреждение от лидеров сообщества с разъяснением характера нарушения и объяснением, почему поведение было неуместным. Может быть запрошено публичное извинение.

### 2. Предупреждение

**Влияние на сообщество**: Нарушение, совершенное в результате единичного инцидента или серии действий.

**Последствие**: Предупреждение с последствиями за продолжение подобного поведения. Запрет на взаимодействие с вовлеченными лицами, включая нежелательное взаимодействие с теми, кто обеспечивает соблюдение Кодекса поведения, на определенный период времени. Это включает избегание взаимодействий в пространствах сообщества, а также на внешних каналах, таких как социальные сети. Нарушение этих условий может привести к временному или постоянному бану.

### 3. Временный бан

**Влияние на сообщество**: Серьезное нарушение стандартов сообщества, включая устойчивое неадекватное поведение.

**Последствие**: Временный запрет на любые виды взаимодействия или публичного общения с сообществом на определенный период времени. В течение этого периода не допускается никакое публичное или частное взаимодействие с вовлеченными лицами, включая нежелательное взаимодействие с теми, кто обеспечивает соблюдение Кодекса поведения. Нарушение этих условий может привести к постоянному бану.

### 4. Постоянный бан

**Влияние на сообщество**: Демонстрация устойчивой модели нарушения стандартов сообщества, включая постоянное недопустимое поведение, преследование отдельного лица или агрессию в отношении или унижение групп лиц.

**Последствие**: Постоянный запрет на любые виды публичного взаимодействия в рамках сообщества.

## Атрибуция

Этот Кодекс поведения адаптирован из [Contributor Covenant][homepage],  
версия 2.0, доступная по адресу  
https://www.contributor-covenant.org/version/2/0/code_of_conduct.html.  

Руководство по влиянию на сообщество вдохновлено [лестницей применения кодекса поведения Mozilla](https://github.com/mozilla/diversity).  

[homepage]: https://www.contributor-covenant.org  

Ответы на часто задаваемые вопросы о данном кодексе поведения можно найти в разделе FAQ по адресу  
https://www.contributor-covenant.org/faq. Переводы доступны на  
https://www.contributor-covenant.org/translations.

<div align="right"> 
<h6><small>Часть содержимого этой страницы была переведена GPT и может содержать ошибки.</small></h6>